package com.jz.dmp.modules.service;

import com.jz.common.constant.JsonResult;
import com.jz.dmp.modules.controller.dataService.bean.ApiInterfaceInfoListReq;
import com.jz.dmp.modules.controller.dataService.bean.ApiInterfaceReq;
import com.jz.dmp.modules.controller.dataService.bean.CreateFolderReq;
import com.jz.dmp.modules.controller.dataService.bean.MakeBigDataApiReq;
import com.jz.dmp.modules.model.DvRuleT;

import java.util.List;

/**
 * 数据服务-服务管理--调用gateway 接口
 *
 * @author Bellamy
 * @since 2021-01-18 10:56:18
 */
public interface DmpApiServiceMangeService {

    /**
     * 保存/编辑API(第三方)基本信息
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    JsonResult saveApiInfo(ApiInterfaceReq req) throws Exception;

    /**
     * 制作/编辑API(大数据查询/标签查询)
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    JsonResult saveApiBigDataInfo(ApiInterfaceReq req) throws Exception;

    /**
     * 编辑API(第三方)基本信息
     *
     * @author Bellamy
     * @since 2021-01-20
     */
    JsonResult updateApiInfo(ApiInterfaceReq req) throws Exception;

    /**
     * 编辑API(大数据查询/标签查询)
     *
     * @author Bellamy
     * @since 2021-01-20
     */
    JsonResult updateApiBigDataInfo(MakeBigDataApiReq req) throws Exception;

    /**
     * API计量调用次数和执行时长
     *
     * @author Bellamy
     * @since 2021-01-20
     */
    JsonResult getCountAPiCallStat() throws Exception;

    /**
     * 获取数据源库——下拉框
     *
     * @return
     * @author Bellamy
     */
    JsonResult querygSourceDbList(Integer projectId, String dbName) throws Exception;

    /**
     * 配置数据源——下拉框
     *
     * @return
     * @author Bellamy
     * @since 2021-01-21
     */
    JsonResult getSourceSetting() throws Exception;

    /**
     * API计量--API未调用列表
     *
     * @author Bellamy
     * @since 2021-01-22
     */
    JsonResult queryApiNotCalledListPage(ApiInterfaceInfoListReq req) throws Exception;

    /**
     * 服务开发API列表
     *
     * @author Bellamy
     * @since 2021-02-24
     */
    JsonResult apiListPaging(ApiInterfaceInfoListReq req) throws Exception;

    /**
     * 获取文件夹列表
     *
     * @return
     * @author Bellamy
     * @since 2021-02-24
     */
    JsonResult getFolderTree(String projectId, String orgFolder) throws Exception;

    /**
     * API计量--API已调用列表
     *
     * @author Bellamy
     * @since 2021-02-25
     */
    JsonResult listCallApi(ApiInterfaceInfoListReq req) throws Exception;

    /**
     * 服务开发---获取ApiId
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    JsonResult getApiId() throws Exception;

    /**
     * 创建项目文件夹
     *
     * @author Bellamy
     * @since 2021-02-24
     */
    JsonResult createProjectFolder(CreateFolderReq req) throws Exception;

    /**
     * 删除文件夹
     *
     * @return
     * @author Bellamy
     * @since 2021-03-3
     */
    JsonResult delFolderById(String id) throws Exception;

    /**
     * 获取function模板列表
     *
     * @return
     * @author Bellamy
     * @since 2021-03-3
     */
    JsonResult getFunctionTemplateList() throws Exception;
}